var NAVTREEINDEX1 =
{
"classAlgebraicKernel__d__2_1_1NumberOfSolutions__2.html#a6be16f0f2da771011675867172003d73":[1,0,0,0,12,1],
"classAlgebraicKernel__d__2_1_1NumberOfSolutions__2.html#aa93f8fb1a9fe7229c8fbe5030329c5fc":[1,0,0,0,12,2],
"classAlgebraicKernel__d__2_1_1NumberOfSolutions__2.html#accf9c52cfbcd43e8b6e66af6f2c6c73a":[1,0,0,0,12,3],
"classAlgebraicKernel__d__2_1_1SignAt__2.html":[1,0,0,0,25],
"classAlgebraicKernel__d__2_1_1SignAt__2.html#a4781083223961032b9cf7c86f44143f0":[1,0,0,0,25,2],
"classAlgebraicKernel__d__2_1_1SignAt__2.html#a67a331d620299d082f8f06697fb94516":[1,0,0,0,25,1],
"classAlgebraicKernel__d__2_1_1SignAt__2.html#a7b968a95322be66cc294f2ca71003477":[1,0,0,0,25,0],
"classAlgebraicKernel__d__2_1_1SignAt__2.html#a9d7df92d198f989d38d49225aa68dd3e":[1,0,0,0,25,3],
"classAlgebraicKernel__d__2_1_1Solve__2.html":[1,0,0,0,13],
"classAlgebraicKernel__d__2_1_1Solve__2.html#a018e952909c222963e4bff4b70d94e00":[1,0,0,0,13,0],
"classAlgebraicKernel__d__2_1_1Solve__2.html#a38ca9c46ab9010173be9cf359f824a5f":[1,0,0,0,13,1],
"classAlgebraicKernel__d__2_1_1SquareFreeFactorize__2.html":[1,0,0,0,20],
"classAlgebraicKernel__d__2_1_1SquareFreeFactorize__2.html#a69a2c5c3cb5c7d1c1b869380ea9c458d":[1,0,0,0,20,0],
"classCGAL_1_1Algebraic__kernel__d__1.html":[1,0,1,0],
"classCGAL_1_1Algebraic__kernel__d__1.html#a0d6b69492fa52c0ac8cd08d147cd319c":[1,0,1,0,0],
"classCGAL_1_1Algebraic__kernel__d__1.html#a19daa175c1f8ec32bf1f8d93bf31732a":[1,0,1,0,3],
"classCGAL_1_1Algebraic__kernel__d__1.html#a50e4c74eb3b787c25bf038c6df8746b5":[1,0,1,0,4],
"classCGAL_1_1Algebraic__kernel__d__1.html#a55519afb9e4891c467dfba5b791eb4cd":[1,0,1,0,1],
"classCGAL_1_1Algebraic__kernel__d__1.html#aede09ed559fdb29547f0c12b9c5beb71":[1,0,1,0,2],
"classCGAL_1_1Algebraic__kernel__d__2.html":[1,0,1,1],
"classCGAL_1_1Algebraic__kernel__d__2.html#a0b91e1f1606c2fea0d65b774406eaae9":[1,0,1,1,1],
"classCGAL_1_1Algebraic__kernel__d__2.html#a2dd9e502e21e3a16d97340bdb98c5fa9":[1,0,1,1,2],
"classCGAL_1_1Algebraic__kernel__d__2.html#a56464cc4a40d5a3164c84f4dde2bfbd6":[1,0,1,1,3],
"classCGAL_1_1Algebraic__kernel__d__2.html#ae2a0173a781c1569be3814f3ebae6393":[1,0,1,1,0],
"classCGAL_1_1Algebraic__kernel__d__2.html#ae4eb6a9c1525552ae219b72d4572b676":[1,0,1,1,4],
"examples.html":[4],
"group__PkgAlgebraicKernelDConcepts.html":[1,0,0],
"group__PkgAlgebraicKernelDConceptsBi.html":[1,0,0,0],
"group__PkgAlgebraicKernelDConceptsUni.html":[1,0,0,1],
"group__PkgAlgebraicKernelDModels.html":[1,0,1],
"group__PkgAlgebraicKernelDRef.html":[1,0],
"index.html":[0],
"index.html":[],
"index.html#Algebraic_kernel_dAlgebraic":[0,1],
"index.html#Algebraic_kernel_dAuxiliaryFunctionality":[0,1,5],
"index.html#Algebraic_kernel_dBivariateAlgebraicKernel":[0,1,7],
"index.html#Algebraic_kernel_dComparisonandApproximation":[0,1,3],
"index.html#Algebraic_kernel_dConstructionofAlgebraic":[0,1,2],
"index.html#Algebraic_kernel_dDesign":[0,4],
"index.html#Algebraic_kernel_dDesignRationale":[0,1,6],
"index.html#Algebraic_kernel_dExamples":[0,3],
"index.html#Algebraic_kernel_dGenericAlgebraicKernels":[0,2,0],
"index.html#Algebraic_kernel_dInterplaywithPolynomials":[0,1,4],
"index.html#Algebraic_kernel_dIntroduction":[0,0],
"index.html#Algebraic_kernel_dMajorTypes":[0,1,1],
"index.html#Algebraic_kernel_dModels":[0,2],
"index.html#Algebraic_kernel_dUnivariateAlgebraicKernel":[0,1,0],
"index.html#CGALAK1ConstructionExamples":[0,3,0],
"index.html#CGALAK1EGCompare_1":[0,3,2],
"index.html#CGALAK1EGIsolate_1":[0,3,3],
"index.html#CGALAK1EGSign_at_1":[0,3,4],
"index.html#CGALAK1Solving":[0,3,1],
"modules.html":[1],
"pages.html":[]
};
